cgexplore.molecular.BeadLibrary
===============================

.. currentmodule:: cgexplore.molecular

.. autoclass:: BeadLibrary
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~BeadLibrary.get_cgbead_from_class
      ~BeadLibrary.get_cgbead_from_element
      ~BeadLibrary.get_cgbead_from_type
   
   

   
   
   